@@ -18,7 +18,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"net/url"
 	"os"
@@ -596,6 +595,8 @@ func RunAppsGetLogs(c *CmdConfig) error {
 		logType = godo.AppLogTypeDeploy
 	case strings.ToLower(string(godo.AppLogTypeRun)):
 		logType = godo.AppLogTypeRun
+	case strings.ToLower(string(godo.AppLogTypeRunRestarted)):
+		logType = godo.AppLogTypeRunRestarted
 	default:
 		return fmt.Errorf("Invalid log type %s", logTypeStr)
 	}
@@ -705,9 +706,9 @@ Optionally, pass a deployment ID to get the spec of that specific deployment.`,
 	AddStringFlag(getCmd, doctl.ArgAppDeployment, "", "", "optional: a deployment ID")
 	AddStringFlag(getCmd, doctl.ArgFormat, "", "yaml", `the format to output the spec in; either "yaml" or "json"`)
 
-	validateCmd := CmdBuilder(cmd, RunAppsSpecValidate, "validate <spec file>", "Validate an application spec", `Use this command to check whether a given app spec (YAML or JSON) is valid.
+	validateCmd := cmdBuilderWithInit(cmd, RunAppsSpecValidate, "validate <spec file>", "Validate an application spec", `Use this command to check whether a given app spec (YAML or JSON) is valid.
 
-You may pass - as the filename to read from stdin.`, Writer)
+You may pass - as the filename to read from stdin.`, Writer, false)
 	AddBoolFlag(validateCmd, doctl.ArgSchemaOnly, "", false, "Only validate the spec schema and not the correctness of the spec.")
 
 	return cmd
@@ -763,6 +764,7 @@ func RunAppsSpecGet(c *CmdConfig) error {
 }
 
 // RunAppsSpecValidate validates an app spec file
+// doesn't require auth & connection to the API with doctl.ArgSchemaOnly flag
 func RunAppsSpecValidate(c *CmdConfig) error {
 	if len(c.Args) < 1 {
 		return doctl.NewMissingArgsErr(c.NS)
@@ -779,6 +781,7 @@ func RunAppsSpecValidate(c *CmdConfig) error {
 		return err
 	}
 
+	// validate schema only (offline)
 	if schemaOnly {
 		ymlSpec, err := yaml.Marshal(appSpec)
 		if err != nil {
@@ -788,6 +791,10 @@ func RunAppsSpecValidate(c *CmdConfig) error {
 		return err
 	}
 
+	// validate the spec against the API
+	if err := c.initServices(c); err != nil {
+		return err
+	}
 	res, err := c.Apps().Propose(&godo.AppProposeRequest{
 		Spec: appSpec,
 	})
@@ -953,7 +960,7 @@ func readAppAlertDestination(stdin io.Reader, path string) (*godo.AlertDestinati
 		alertDestinations = alertDestinationsFile
 	}
 
-	byt, err := ioutil.ReadAll(alertDestinations)
+	byt, err := io.ReadAll(alertDestinations)
 	if err != nil {
 		return nil, fmt.Errorf("reading app alert destinations: %w", err)
 	}
