@@ -70,43 +70,47 @@ func Registry() *Command {
 	cmd.AddCommand(GarbageCollection())
 	cmd.AddCommand(RegistryOptions())
 
-	createRegDesc := "This command creates a new private container registry with the provided name."
+	createRegDesc := "Creates a new private container registry with the provided name."
 	cmdRunRegistryCreate := CmdBuilder(cmd, RunRegistryCreate, "create <registry-name>",
 		"Create a private container registry", createRegDesc, Writer)
 	AddStringFlag(cmdRunRegistryCreate, doctl.ArgSubscriptionTier, "", "basic",
-		"Subscription tier for the new registry. Possible values: see `doctl registry options subscription-tiers`", requiredOpt())
+		"Subscription tier for the new registry. For a list of possible values, use the `doctl registry options subscription-tiers` command.", requiredOpt())
 	AddStringFlag(cmdRunRegistryCreate, doctl.ArgRegionSlug, "", "",
-		"Region for the new registry. Possible values: see `doctl registry options available-regions`")
+		"A slug indicating which datacenter region the registry reside in. For a list of supported region slugs, use the `doctl registry options available-regions` command")
+	cmdRunRegistryCreate.Example = `The following example creates a registry named ` + "`" + `example-registry` + "`" + ` in the NYC3 region: doctl registry create example-registry --region=nyc3`
 
-	getRegDesc := "This command retrieves details about a private container registry including its name and the endpoint used to access it."
-	CmdBuilder(cmd, RunRegistryGet, "get", "Retrieve details about a container registry",
+	getRegDesc := "Retrieves details about a private container registry, including its name and the endpoint used to access it."
+	cmdRegistryGet := CmdBuilder(cmd, RunRegistryGet, "get", "Retrieve details about a container registry",
 		getRegDesc, Writer, aliasOpt("g"), displayerType(&displayers.Registry{}))
+	cmdRegistryGet.Example = `The following example retrieves details about a registry named ` + "`" + `example-registry` + "`" + `: doctl registry get example-registry`
 
-	deleteRegDesc := "This command permanently deletes a private container registry and all of its contents."
+	deleteRegDesc := "Permanently deletes a private container registry and all of its contents. This is irreversible."
 	cmdRunRegistryDelete := CmdBuilder(cmd, RunRegistryDelete, "delete",
 		"Delete a container registry", deleteRegDesc, Writer, aliasOpt("d", "del", "rm"))
-	AddBoolFlag(cmdRunRegistryDelete, doctl.ArgForce, doctl.ArgShortForce, false, "Force registry delete")
+	AddBoolFlag(cmdRunRegistryDelete, doctl.ArgForce, doctl.ArgShortForce, false, "Force deletes the registry without confirmation prompt")
+	cmdRunRegistryDelete.Example = `The following example deletes a registry named ` + "`" + `example-registry` + "`" + `: doctl registry delete example-registry`
 
-	loginRegDesc := "This command logs in Docker so that pull and push commands to your private container registry will be authenticated."
+	loginRegDesc := "Logs Docker into Container Registry making pull and push commands to your private container registry authenticated."
 	cmdRegistryLogin := CmdBuilder(cmd, RunRegistryLogin, "login", "Log in Docker to a container registry",
 		loginRegDesc, Writer)
 	AddIntFlag(cmdRegistryLogin, doctl.ArgRegistryExpirySeconds, "", 0,
-		"The length of time the registry credentials will be valid for in seconds. By default, the credentials expire after 30 days.")
+		"The length of time the registry credentials are valid for, in seconds. By default, the credentials expire after 30 days.")
 	AddBoolFlag(cmdRegistryLogin, doctl.ArgRegistryReadOnly, "", false,
-		"If true, the DigitalOcean API token generated by the login command will be read-only, causing any push operations to fail. By default, the API token is read-write.")
+		"Sets the DigitalOcean API token generated by the login command to read-only, causing any push operations to fail. By default, the API token is read-write.")
 	AddBoolFlag(cmdRegistryLogin, doctl.ArgRegistryNeverExpire, "", false,
-		"If true, the DigitalOcean API token generated by the login command will never expire. By default, this is false.")
+		"Sets the DigitalOcean API token generated by the login command to never expire. By default, this is set to false.")
+	cmdRegistryLogin.Example = `The following example logs Docker into a registry and provides Docker with read-only credentials: doctl registry login --read-only=true`
 
 	logoutRegDesc := "This command logs Docker out of the private container registry, revoking access to it."
 	cmdRunRegistryLogout := CmdBuilder(cmd, RunRegistryLogout, "logout", "Log out Docker from a container registry",
 		logoutRegDesc, Writer)
 	AddStringFlag(cmdRunRegistryLogout, doctl.ArgRegistryAuthorizationServerEndpoint, "", oauthTokenRevokeEndpoint, "The endpoint of the OAuth authorization server used to revoke credentials on logout.")
 
-	kubeManifestDesc := `This command outputs a YAML-formatted Kubernetes secret manifest that can be used to grant a Kubernetes cluster pull access to your private container registry.
+	kubeManifestDesc := `Outputs a YAML-formatted Kubernetes secret manifest that can be used to grant a Kubernetes cluster pull access to your private container registry.
 
-By default, the secret manifest will be applied to all the namespaces for the Kubernetes cluster using the DOSecret operator. The DOSecret operator is available on clusters running version 1.15.12-do.2 or greater. For older clusters or to restrict the secret to a specific namespace, use the --namespace flag.
+By default, the secret manifest is applied to all the namespaces for the Kubernetes cluster using the DOSecret operator. The DOSecret operator is available on clusters running version 1.15.12-do.2 or greater. For older clusters, or to restrict the secret to a specific namespace, use the ` + "`" + `--namespace` + "`" + ` flag.
 
-Redirect the command's output to a file to save the manifest for later use or pipe it directly to kubectl to create the secret in your cluster:
+You can redirect the command's output to a file to save the manifest for later use or pipe it directly to ` + "`" + `kubectl` + "`" + ` to create the secret in your cluster:
 
     doctl registry kubernetes-manifest | kubectl apply -f -
 `
@@ -114,21 +118,23 @@ Redirect the command's output to a file to save the manifest for later use or pi
 		"Generate a Kubernetes secret manifest for a registry.",
 		kubeManifestDesc, Writer, aliasOpt("k8s"))
 	AddStringFlag(cmdRunKubernetesManifest, doctl.ArgObjectName, "", "",
-		"The secret name to create. Defaults to the registry name prefixed with \"registry-\"")
+		"The secret's name. Defaults to the registry name prefixed with \"registry-\"")
 	AddStringFlag(cmdRunKubernetesManifest, doctl.ArgObjectNamespace, "",
 		"kube-system", "The Kubernetes namespace to hold the secret")
+	cmdRunKubernetesManifest.Example = `The following example generates a secret manifest for a registry named ` + "`" + `example-registry` + "`" + ` and applies it to the ` + "`" + `kube-system` + "`" + ` namespace: doctl registry kubernetes-manifest example-registry --namespace=kube-system`
 
-	dockerConfigDesc := `This command outputs a JSON-formatted Docker configuration that can be used to configure a Docker client to authenticate with your private container registry. This configuration is useful for configuring third-party tools that need access to your registry. For configuring your local Docker client use "doctl registry login" instead, as it will preserve the configuration of any other registries you have authenticated to.
+	dockerConfigDesc := `Outputs a JSON-formatted Docker configuration that you can use to configure a Docker client to authenticate with your private container registry. This configuration is useful for configuring third-party tools that need access to your registry. For configuring your local Docker client use ` + "`" + `doctl registry login` + "`" + ` instead, as it preserves the configuration of any other registries you have authenticated to.
 
-By default this command generates read-only credentials. Use the --read-write flag to generate credentials that can push. The configuration produced by this command contains a DigitalOcean API token that can be used to access your account, so be sure to keep it secret.`
+By default this command generates read-only credentials. Use the ` + "`" + `--read-write` + "`" + ` flag to generate credentials that can push. The configuration produced by this command contains a DigitalOcean API token that can be used to access your account and should be treated as sensitive information.`
 
 	cmdRunDockerConfig := CmdBuilder(cmd, RunDockerConfig, "docker-config",
-		"Generate a docker auth configuration for a registry",
+		"Generate a Docker auth configuration for a registry",
 		dockerConfigDesc, Writer, aliasOpt("config"))
 	AddBoolFlag(cmdRunDockerConfig, doctl.ArgReadWrite, "", false,
-		"Generate credentials that can push to your registry")
+		"Generates credentials that can push to your registry")
 	AddIntFlag(cmdRunDockerConfig, doctl.ArgRegistryExpirySeconds, "", 0,
-		"The length of time the registry credentials will be valid for in seconds. By default, the credentials do not expire.")
+		"The length of time the registry credentials are valid for, in seconds. By default, the credentials do not expire.")
+	cmdRunDockerConfig.Example = `The following example generates a Docker configuration for a registry named ` + "`" + `example-registry` + "`" + ` and uses the ` + "`" + `--expiry-seconds` + "`" + ` to set the credentials to expire after one day: doctl registry docker-config example-registry --expiry-seconds=86400`
 
 	return cmd
 }
@@ -140,26 +146,27 @@ func Repository() *Command {
 			Use:     "repository",
 			Aliases: []string{"repo", "r"},
 			Short:   "Display commands for working with repositories in a container registry",
-			Long:    "The subcommands of `doctl registry repository` help you command actions related to a repository.",
+			Long:    "The subcommands of `doctl registry repository` allow you to manage various properties of your repository.",
 		},
 	}
 
-	listRepositoriesDesc := `This command retrieves information about repositories in a registry, including:
+	listRepositoriesDesc := `Retrieves information about repositories in a registry, including:
   - The repository name
-  - The latest tag of the repository
+  - The latest tag for the repository
   - The compressed size for the latest tag
   - The manifest digest for the latest tag
   - The last updated timestamp
 `
-	CmdBuilder(
+	cmdListRepositories := CmdBuilder(
 		cmd,
 		RunListRepositories, "list",
 		"List repositories for a container registry", listRepositoriesDesc,
 		Writer, aliasOpt("ls"), displayerType(&displayers.Repository{}),
 		hiddenCmd(),
 	)
+	cmdListRepositories.Example = `The following example lists repositories in a registry named ` + "`" + `example-registry` + "`" + ` and uses the ` + "`" + `--format` + "`" + ` flag to return only the name and update time of each repository: doctl registry repository list example-registry --format Name,UpdatedAt`
 
-	listRepositoriesV2Desc := `This command retrieves information about repositories in a registry, including:
+	listRepositoriesV2Desc := `Retrieves information about repositories in a registry, including:
   - The repository name
   - The latest manifest of the repository
   - The latest manifest's latest tag, if any
@@ -167,27 +174,29 @@ func Repository() *Command {
   - The number of manifests in the repository
 `
 
-	CmdBuilder(
+	cmdListRepositoriesV2 := CmdBuilder(
 		cmd,
 		RunListRepositoriesV2, "list-v2",
 		"List repositories for a container registry", listRepositoriesV2Desc,
 		Writer, aliasOpt("ls2"), displayerType(&displayers.Repository{}),
 	)
+	cmdListRepositoriesV2.Example = `The following example lists repositories in a registry named ` + "`" + `example-registry` + "`" + ` and uses the ` + "`" + `--format` + "`" + ` flag to return only the name and update time of each repository: doctl registry repository list-v2 example-registry --format Name,UpdatedAt`
 
-	listRepositoryTagsDesc := `This command retrieves information about tags in a repository, including:
+	listRepositoryTagsDesc := `Retrieves information about tags in a repository, including:
   - The tag name
   - The compressed size
   - The manifest digest
   - The last updated timestamp
 `
-	CmdBuilder(
+	cmdListRepositoryTags := CmdBuilder(
 		cmd,
 		RunListRepositoryTags, "list-tags <repository>",
 		"List tags for a repository in a container registry", listRepositoryTagsDesc,
 		Writer, aliasOpt("lt"), displayerType(&displayers.RepositoryTag{}),
 	)
+	cmdListRepositoryTags.Example = `The following example lists tags in a repository named ` + "`" + `example-repository` + "`" + ` in a registry named ` + "`" + `example-registry` + "`" + `. The command also uses the ` + "`" + `--format` + "`" + ` flag to return only the tag name and manifest digest for each tag: doctl registry repository list-tags example-registry/example-repository --format Tag,ManifestDigest`
 
-	deleteTagDesc := "This command permanently deletes one or more repository tags."
+	deleteTagDesc := "Permanently deletes one or more repository tags."
 	cmdRunRepositoryDeleteTag := CmdBuilder(
 		cmd,
 		RunRepositoryDeleteTag,
@@ -197,9 +206,10 @@ func Repository() *Command {
 		Writer,
 		aliasOpt("dt"),
 	)
-	AddBoolFlag(cmdRunRepositoryDeleteTag, doctl.ArgForce, doctl.ArgShortForce, false, "Force tag deletion")
+	AddBoolFlag(cmdRunRepositoryDeleteTag, doctl.ArgForce, doctl.ArgShortForce, false, "Delete tag without confirmation prompt")
+	cmdRunRepositoryDeleteTag.Example = `The following example deletes a tag named ` + "`" + `web` + "`" + ` from a repository named ` + "`" + `example-repository` + "`" + ` in a registry named ` + "`" + `example-registry` + "`" + `: doctl registry repository delete-tag example-registry/example-repository web`
 
-	listRepositoryManifests := `This command retrieves information about manifests in a repository, including:
+	listRepositoryManifests := `Retrieves information about manifests in a repository, including:
   - The manifest digest
   - The compressed size
   - The uncompressed size
@@ -207,14 +217,15 @@ func Repository() *Command {
   - The manifest tags
   - The manifest blobs (available in detailed output only)
 `
-	CmdBuilder(
+	cmdListRepositoryManifests := CmdBuilder(
 		cmd,
 		RunListRepositoryManifests, "list-manifests <repository>",
 		"List manifests for a repository in a container registry", listRepositoryManifests,
 		Writer, aliasOpt("lm"), displayerType(&displayers.RepositoryManifest{}),
 	)
+	cmdListRepositoryManifests.Example = `The following example lists manifests in a repository named ` + "`" + `example-repository` + "`" + ` in a registry named ` + "`" + `example-registry` + "`" + `. The command also uses the ` + "`" + `--format` + "`" + ` flag to return only the digest and update time for each manifest: doctl registry repository list-manifests example-registry/example-repository --format Digest,UpdatedAt`
 
-	deleteManifestDesc := "This command permanently deletes one or more repository manifests by digest."
+	deleteManifestDesc := "Permanently deletes one or more repository manifests by digest."
 	cmdRunRepositoryDeleteManifest := CmdBuilder(
 		cmd,
 		RunRepositoryDeleteManifest,
@@ -224,7 +235,8 @@ func Repository() *Command {
 		Writer,
 		aliasOpt("dm"),
 	)
-	AddBoolFlag(cmdRunRepositoryDeleteManifest, doctl.ArgForce, doctl.ArgShortForce, false, "Force manifest deletion")
+	AddBoolFlag(cmdRunRepositoryDeleteManifest, doctl.ArgForce, doctl.ArgShortForce, false, "Deletes manifest without confirmation prompt")
+	cmdRunRepositoryDeleteManifest.Example = `The following example deletes a manifest with digest ` + "`" + `sha256:1234567890abcdef` + "`" + ` from a repository named ` + "`" + `example-repository` + "`" + ` in a registry named ` + "`" + `example-registry` + "`" + `: doctl registry repository delete-manifest example-registry/example-repository sha256:a67c20e45178d90cbe686575719bd81f279b06842dc77521690e292c1eea685`
 
 	return cmd
 }
@@ -236,11 +248,11 @@ func GarbageCollection() *Command {
 			Use:     "garbage-collection",
 			Aliases: []string{"gc", "g"},
 			Short:   "Display commands for garbage collection for a container registry",
-			Long:    "The subcommands of `doctl registry garbage-collection` start a garbage collection, retrieve or cancel a currently-active garbage collection or list past garbage collections for a specified registry.",
+			Long:    "The subcommands of `doctl registry garbage-collection` start a garbage collection, retrieve or cancel a currently-active garbage collection, or list past garbage collections for a specified registry.",
 		},
 	}
 
-	runStartGarbageCollectionDesc := "This command starts a garbage collection on a container registry. There can be only one active garbage collection at a time for a given registry."
+	runStartGarbageCollectionDesc := "Starts a garbage collection on a container registry. You can only have one active garbage collection at a time for a given registry."
 	cmdStartGarbageCollection := CmdBuilder(
 		cmd,
 		RunStartGarbageCollection,
@@ -256,19 +268,20 @@ func GarbageCollection() *Command {
 	AddBoolFlag(cmdStartGarbageCollection, doctl.ArgGCExcludeUnreferencedBlobs, "", false,
 		"Exclude unreferenced blobs from garbage collection.")
 	AddBoolFlag(cmdStartGarbageCollection, doctl.ArgForce, doctl.ArgShortForce, false, "Run garbage collection without confirmation prompt")
+	cmdStartGarbageCollection.Example = `The following example starts a garbage collection on a registry named ` + "`" + `example-registry` + "`" + `: doctl registry garbage-collection start example-registry`
 
 	gcInfoIncluded := `
   - UUID
   - Status
-  - Registry Name
-  - Created At
-  - Updated At
-  - Blobs Deleted
-  - Freed Bytes
+  - Registry name
+  - Create time
+  - Updated at time
+  - Blobs deleted
+  - Freed bytes
 `
 
-	runGetGarbageCollectionDesc := "This command retrieves the currently-active garbage collection for a container registry, if any active garbage collection exists. Information included about the registry includes:" + gcInfoIncluded
-	CmdBuilder(
+	runGetGarbageCollectionDesc := "Retrieves the currently-active garbage collection for a container registry, if any active garbage collection exists. Information included about the registry includes:" + gcInfoIncluded
+	cmdGetGarbageCollection := CmdBuilder(
 		cmd,
 		RunGetGarbageCollection,
 		"get-active",
@@ -278,9 +291,10 @@ func GarbageCollection() *Command {
 		aliasOpt("ga", "g"),
 		displayerType(&displayers.GarbageCollection{}),
 	)
+	cmdGetGarbageCollection.Example = `The following example retrieves the currently-active garbage collection for a registry: doctl registry garbage-collection get-active`
 
-	runListGarbageCollectionsDesc := "This command retrieves a list of past garbage collections for a registry. Information about each garbage collection includes:" + gcInfoIncluded
-	CmdBuilder(
+	runListGarbageCollectionsDesc := "Retrieves a list of past garbage collections for a registry. Information about each garbage collection includes:" + gcInfoIncluded
+	cmdListGarbageCollections := CmdBuilder(
 		cmd,
 		RunListGarbageCollections,
 		"list",
@@ -290,9 +304,10 @@ func GarbageCollection() *Command {
 		aliasOpt("ls", "l"),
 		displayerType(&displayers.GarbageCollection{}),
 	)
+	cmdListGarbageCollections.Example = `The following example retrieves a list of past garbage collections for a registry: doctl registry garbage-collection list`
 
-	runCancelGarbageCollectionDesc := "This command cancels the currently-active garbage collection for a container registry."
-	CmdBuilder(
+	runCancelGarbageCollectionDesc := "Cancels the currently-active garbage collection for a container registry."
+	cmdCancelGarbageCollection := CmdBuilder(
 		cmd,
 		RunCancelGarbageCollection,
 		"cancel",
@@ -301,6 +316,7 @@ func GarbageCollection() *Command {
 		Writer,
 		aliasOpt("c"),
 	)
+	cmdCancelGarbageCollection.Example = `The following example cancels the currently-active garbage collection for a registry: doctl registry garbage-collection cancel`
 
 	return cmd
 }
@@ -316,9 +332,9 @@ func RegistryOptions() *Command {
 		},
 	}
 
-	tiersDesc := "List available container registry subscription tiers"
+	tiersDesc := "Lists available container registry subscription tiers"
 	CmdBuilder(cmd, RunRegistryOptionsTiers, "subscription-tiers", tiersDesc, tiersDesc, Writer, aliasOpt("tiers"))
-	regionsDesc := "List available container registry regions"
+	regionsDesc := "Lists available container registry regions"
 	CmdBuilder(cmd, RunGetRegistryOptionsRegions, "available-regions", regionsDesc, regionsDesc, Writer, aliasOpt("regions"))
 
 	return cmd
